// 导入 Vue 创建应用的核心函数
import { createApp } from 'vue'
// 导入根组件
import App from './App.vue'
// 导入重置样式，清除浏览器默认样式
import './assets/style/reset.css'
// 导入路由配置
import router from './router'
// 导入状态管理库 Pinia 实例
import pinia from './store'
// 导入 Vant UI 组件库样式
import 'vant/lib/index.css'
// 导入animate.css动画库
import 'animate.css'
// 导入自定义吸顶组件
import StickyBar from './components/StickyBar.vue'

// 导入全局方法
import globalMethods from './utils/globalMethods'
// 导入自定义指令集合
import directives from './directives'

// 创建 Vue 应用实例
const app = createApp(App)

// 注册全局组件
app.component('StickyBar', StickyBar)
// 使用路由插件
app.use(router)
// 使用 Pinia 状态管理
app.use(pinia)
// 注册全局自定义指令
app.use(directives)
// 注册全局方法
app.use(globalMethods)
// 挂载应用到 DOM
app.mount('#app')
